@@ -5,29 +5,34 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expressi
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class C_NotEquals extends C_Expression {
 	private static final long serialVersionUID = 7587723477959909679L;
-	protected String id="NotEquals";
+	protected String id = "NotEquals";
 	protected C_Expression leftArgument;
 	protected C_Expression rightArgument;
 
-	public C_NotEquals(){
-		
+	public C_NotEquals() {
+
 	}
-	
+
 	public C_NotEquals(C_Expression leftArgument, C_Expression rightArgument) {
 		this.leftArgument = leftArgument;
 		this.rightArgument = rightArgument;
+		if (leftArgument != null && rightArgument != null) {
+			this.readableExpression = "NotEquals("
+					+ leftArgument.getReadableExpression() + ","
+					+ rightArgument.getReadableExpression() + ")";
+		}
 	}
 
 	public C_OperatorType getOperator() {
 		return C_OperatorType.NOT_EQUALS;
 	}
-	
+
 	public String getReturnedDataType() {
 		return "Boolean";
 	}
@@ -37,7 +42,6 @@ public class C_NotEquals extends C_Expression {
 		return id;
 	}
 
-
 	public C_Expression getLeftArgument() {
 		return leftArgument;
 	}
@@ -59,6 +63,5 @@ public class C_NotEquals extends C_Expression {
 		return "NotEquals [id=" + id + ", leftArgument=" + leftArgument
 				+ ", rightArgument=" + rightArgument + "]";
 	}
-	
-	
+
 }
